<img src="https://raw.githubusercontent.com/Weizhe-Chen/pypolo/main/logo.svg" align="right" width="200" alt="header pic"/>

# PyPolo
PyPolo is a Python library for **informative planning and learning**.

I am still completing the documentation. If you feel like building PyPolo together, please don't hesitate to drop me an email: chenweiz@iu.edu!

# Features
1. **Minimum dependency** &rarr; painless algorithm prototyping and education &rarr; ~~Robot Operating System (ROS)~~.
2. **Readable code, detailed documentation, interactive tutorials** &rarr; easier understanding of the algorithms.
3. **Modular implementation** &rarr; develop new algorithm in the module of your interest.

# Installation
**Requirements**:

* Python >= 3.6 
* PyTorch >= 1.10.2 (NumPy included)
* Matplotlib

```bash
conda create -n pypolo python=3.8
conda activate pypolo
pip install -e .
```
